from mock import MagicMock
import pytest
from syncloud.server.serverfacade import ServerFacade


class TestServerFacade():

    def setup(self):
        self.sam = MagicMock()
        self.sam.update = MagicMock(return_value=True)
        self.sam.upgrade_all = MagicMock(return_value=True)

        self.insider = MagicMock()
        self.insider.set_redirect_info = MagicMock(return_value=True)
        self.insider.acquire_domain = MagicMock(return_value=True)

        self.remote_access = MagicMock()
        self.remote_access.enable = MagicMock(return_value=True)

        self.tools = MagicMock()
        self.tools.id = MagicMock(return_value=True)

    def test_activate_good(self):

        server = ServerFacade(self.sam, self.insider, self.remote_access, self.tools)
        device = server.activate('0.1', 'syncloud.it', 'http://api.syncloud.it', 'test@example.com', 'pass123', 'test')

        assert device == {
            'credentials': {
                'login': 'root',
                'password': 'syncloud',
                'private_key': True},
            'endpoint': {
                'host': 'host',
                'port': 1022
            },
            'id': True,
            'name': 'test.syncloud.it'}

    def test_activate_bad(self):

        self.tools.id = MagicMock()
        self.tools.id.side_effect = Exception('Boom!')

        server = ServerFacade(self.sam, self.insider, self.remote_access, self.tools)

        with pytest.raises(Exception):
            server.activate('0.1', 'syncloud.it', 'http://api.syncloud.it', 'test@example.com', 'pass123', 'test')